Templates class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- androidSettingsGradleKts → String
-
no setter
- appController → String
-
no setter
- appErrors → String
-
no setter
- appPages → String
-
no setter
- appRoutes → String
-
no setter
- appRoutesGoRouter → String
-
no setter
- flavorizrConfig → String
-
no setter
- flutterLauncherIconsConfig → String
-
no setter
- supportLanguage → String
-
no setter
- themesBarrel → String
-
no setter
Static Methods
-
androidAppBuildGradleKts(
String namespace, String applicationId) → String -
app(
String importPrefix) → String -
appBinding(
String importPrefix) → String -
appConfig(
String importPrefix) → String -
appConstants(
{String languages = ''}) → String -
appGoRouter(
String importPrefix) → String -
appPagesGoRouter(
String importPrefix) → String -
appTranslations(
String importPrefix) → String -
barrel(
String name) → String -
binding(
String name, String importPrefix) → String -
controller(
String name) → String -
enTranslation(
String importPrefix) → String -
firebaseOptions(
String importPrefix) → String -
firebaseService(
String importPrefix) → String -
getStorageService(
) → String -
googleServiceInfoPlist(
String flavor) → String -
googleServicesJson(
String flavor) → String -
initialBinding(
String importPrefix, String storageType) → String -
localeHelper(
String importPrefix) → String -
main(
String importPrefix) → String -
mColors(
) → String -
mTextTheme(
String importPrefix) → String -
mTheme(
String importPrefix) → String -
page(
String name, String importPrefix) → String -
subBarrel(
[List< String> exports = const []]) → String -
translationKeys(
String importPrefix) → String -
translations(
String importPrefix) → String