FileUtils class

Constructors

FileUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

copyAsset(String sourcePath, String destPath) Future<void>
createDirectory(String path, {Logger? logger}) → void
createFile(String path, String content, {Logger? logger, bool overwrite = false}) → void